import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { toast } from 'react-toastify';
import axios from 'axios';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function Field(_ref) {
  var label = _ref.label,
      required = _ref.required,
      maxLength = _ref.maxLength,
      minLength = _ref.minLength,
      name = _ref.name,
      value = _ref.value,
      onChange = _ref.onChange,
      placeholder = _ref.placeholder,
      type = _ref.type,
      labelColor = _ref.labelColor,
      input = _ref.input;
  return /*#__PURE__*/React.createElement("label", {
    className: "text-sm" + (labelColor === undefined ? ' text-gray-600' : ''),
    style: labelColor ? {
      color: labelColor
    } : {}
  }, required ? '* ' : '', label, maxLength > 50 ? /*#__PURE__*/React.createElement("textarea", {
    name: name,
    required: required,
    maxLength: maxLength,
    minLength: minLength,
    className: typeof input === 'object' ? "w-full mt-1 mb-2 p-2 border rounded text-lg" + (input.color ? ' text-black' : '') + (input.border ? ' border-gray-600' : '') : 'w-full mt-1 mb-2 p-2 border boder-gray-600 rounded text-lg text-black',
    style: typeof input === 'object' ? {
      backgroundColor: input.background,
      color: input.color,
      borderColor: input.border
    } : {},
    rows: maxLength / 50,
    value: value,
    onChange: onChange,
    placeholder: placeholder,
    type: type
  }) : /*#__PURE__*/React.createElement("input", {
    name: name,
    required: required,
    maxLength: maxLength,
    minLength: minLength,
    className: typeof input === 'object' ? "w-full mt-1 mb-2 p-2 border rounded text-lg" + (input.color ? ' text-black' : '') + (input.border ? ' border-gray-600' : '') : 'w-full mt-1 mb-2 p-2 border boder-gray-600 rounded text-lg text-black',
    style: typeof input === 'object' ? {
      backgroundColor: input.background,
      color: input.color,
      borderColor: input.border
    } : {},
    value: value,
    onChange: onChange,
    placeholder: placeholder,
    type: type
  }));
}

function useNotify() {
  var _useState = useState(undefined),
      currentToast = _useState[0],
      setCurrentToast = _useState[1];

  return function (type, render) {
    if (currentToast) {
      toast.update(currentToast, {
        type: type,
        render: render
      });
    } else {
      setCurrentToast(toast[type](render));
    }
  };
}

function Form(_ref) {
  var title = _ref.title,
      message = _ref.message,
      fields = _ref.fields,
      labels = _ref.labels,
      placeholders = _ref.placeholders,
      onCompleted = _ref.onCompleted,
      colors = _ref.colors,
      onError = _ref.onError,
      button = _ref.button,
      errors = _ref.errors,
      projectID = _ref.projectID,
      formID = _ref.formID,
      input = _ref.input;

  var _useState = useState(fields.reduce(function (obj, item) {
    var _extends2;

    return _extends({}, obj, (_extends2 = {}, _extends2[item.name] = '', _extends2));
  }, {})),
      values = _useState[0],
      setValues = _useState[1];

  var _useState2 = useState(false),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var notify = useNotify();

  function _onChange(_ref2) {
    var _extends3;

    var target = _ref2.target;
    setValues(_extends({}, values, (_extends3 = {}, _extends3[target.name] = target.value, _extends3)));
  }

  function _onSubmit(event) {
    event.preventDefault();

    for (var index = 0; index < fields.length; index++) {
      var currentValue = values[fields[index].name];
      var currentField = fields[index];

      if (fields[index].required && currentValue === '') {
        notify('error', errors[currentField.name] || currentField.name + " is required");
        return;
      }

      switch (currentField.type) {
        case 'text':
          if (currentValue.length < currentField.minLength || currentValue.length > currentField.maxLength) {
            notify('error', errors[currentField.name] || currentField.name + " length should be between " + currentField.minLength + " and " + currentField.maxLength);
            return;
          }

          switch (currentField.format) {
            case 'simple-characters':
              if (!/^[a-zA-ZàáâäãåąčćęèéêëėįìíîïłńòóôöõøùúûüųūÿýżźñçčšžÀÁÂÄÃÅĄĆČĖĘÈÉÊËÌÍÎÏĮŁŃÒÓÔÖÕØÙÚÛÜŲŪŸÝŻŹÑßÇŒÆČŠŽ∂ð ,.'-]+$/.test(currentValue)) {
                notify('error', errors[currentField.name] || currentField.name + " should not contain special characters");
                return;
              }

              break;
          }

          break;

        case 'email':
          if (!/(?:[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*|"(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21\x23-\x5b\x5d-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])*")@(?:(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|\[(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?|[a-z0-9-]*[a-z0-9]:(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21-\x5a\x53-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])+)\])/.test(currentValue)) {
            notify('error', errors[currentField.name] || currentField.name + " should be an email");
            return;
          }

          break;
      }
    }

    setLoading(true);
    axios.post("https://simply-forms.herokuapp.com/projects/" + projectID + "/forms/" + formID + "/responses", values).then(onCompleted)["catch"](onError)["finally"](function () {
      return setLoading(false);
    });
  }

  return /*#__PURE__*/React.createElement("form", {
    onSubmit: _onSubmit
  }, title && /*#__PURE__*/React.createElement("h2", {
    className: "text-xl font-bold",
    style: colors ? {
      color: colors.title || colors
    } : {}
  }, title), message && /*#__PURE__*/React.createElement("p", {
    className: "mt-2 mb-3" + (colors === undefined || colors.message === undefined ? ' text-gray-800' : ''),
    style: colors ? {
      color: colors.message || colors
    } : {}
  }, message), fields.map(function (field) {
    return /*#__PURE__*/React.createElement(Field, _extends({}, field, {
      key: field.name,
      label: labels[field.name],
      value: values[field.name],
      onChange: _onChange,
      labelColor: colors && (colors.label || colors),
      placeholder: placeholders[field.name],
      input: input
    }));
  }), /*#__PURE__*/React.createElement("div", {
    className: "flex justify-end"
  }, /*#__PURE__*/React.createElement("button", {
    type: "submit",
    className: "py-2 px-10 uppercase rounded shadow w-full md:w-auto",
    style: {
      color: button.color || 'text-white',
      backgroundColor: button.background || 'bg-red-700'
    }
  }, loading ? 'Envíando...' : button.label)), /*#__PURE__*/React.createElement("div", {
    className: "flex justify-center mt-2"
  }, /*#__PURE__*/React.createElement("p", {
    className: "text-xs text-gray-600"
  }, "Powered by ", /*#__PURE__*/React.createElement("a", {
    href: "https://forms.simply-development.com",
    target: "_blank",
    rel: "noreferrer",
    className: "font-bold"
  }, "Simply Forms"))));
}
Form.defaultProps = {
  message: undefined,
  labels: {},
  placeholders: {},
  onCompleted: function onCompleted() {},
  onError: function onError() {},
  errors: {},
  colors: undefined,
  input: {}
};
Form.propTypes = {
  projectID: PropTypes.string.isRequired,
  formID: PropTypes.string.isRequired,
  title: PropTypes.string,
  message: PropTypes.string,
  fields: PropTypes.arrayOf(PropTypes.shape({
    name: PropTypes.string.isRequired,
    required: PropTypes.bool,
    type: PropTypes.oneOf(['text', 'email', 'tel']),
    minLength: PropTypes.number,
    maxLength: PropTypes.number,
    format: PropTypes.oneOf(['simple-characters', 'email', ''])
  })).isRequired,
  labels: PropTypes.object,
  placeholders: PropTypes.object,
  onCompleted: PropTypes.func,
  onError: PropTypes.func,
  button: PropTypes.shape({
    label: PropTypes.string.isRequired,
    color: PropTypes.string,
    background: PropTypes.string
  }).isRequired,
  errors: PropTypes.object,
  colors: PropTypes.shape({
    title: PropTypes.string,
    message: PropTypes.string,
    label: PropTypes.string
  }),
  input: PropTypes.shape({
    background: PropTypes.string,
    color: PropTypes.string,
    border: PropTypes.string
  })
};

var index = {
  Form: Form
};

export default index;
export { Form };
//# sourceMappingURL=index.modern.js.map
